isFull property
bool
get
isFull
Checks if the cache is full.
The cache is considered full if it has reached its maximum capacity.
Implementation
bool get isFull => _cache.length >= capacity;
Checks if the cache is full.
The cache is considered full if it has reached its maximum capacity.
bool get isFull => _cache.length >= capacity;