StashBoxEvent class

Represents a change event in a StashBox

Constructors

StashBoxEvent({required StashBoxEventType type, String? key, dynamic value, dynamic oldValue, required DateTime timestamp, bool inTransaction = false, int transactionDepth = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inTransaction bool
Whether this event was part of a transaction
final
key String?
The key that was affected (null for clear events)
final
oldValue → dynamic
The old value (null for add events)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Timestamp when the event occurred
final
transactionDepth int
Transaction depth if in a transaction
final
type StashBoxEventType
The type of event
final
value → dynamic
The new value (null for remove events)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited