FileOperationResult<T> class
Result of a file operation
Constructors
- FileOperationResult({T? data, required bool success, String? error, int attemptCount = 1, StashBoxException? errorWithRetries})
Properties
- attemptCount → int
-
final
- data → T?
-
final
- error → String?
-
final
- errorWithRetries → StashBoxException?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited