LruCache<K, V> class
Properties
-
capacity
→ int
-
Maximum number of items allowed in the cache
final
-
entries
→ Iterable<MapEntry<K, V>>
-
Get all entries in the cache
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isEmpty
→ bool
-
Checks if the cache is empty.
no setter
-
isFull
→ bool
-
Checks if the cache is full.
no setter
-
keys
→ Iterable<K>
-
Get all keys in the cache
no setter
-
length
→ int
-
Current number of items in the cache
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear()
→ void
-
Removes all entries from the cache.
-
containsKey(K key)
→ bool
-
Checks if the given key exists in the cache.
-
get(K key)
→ V?
-
Get the value associated with the given key from the cache.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
put(K key, V value)
→ void
-
Puts the specified key-value pair into the cache.
-
remove(K key)
→ void
-
Removes the specified key from the cache.
Does nothing if the key does not exist in the cache.
-
toString()
→ String
-
A string representation of this object.
inherited